CREATE TABLE `daq_report_base_info`
(
    `id`            int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `file_id`       int(11) NOT NULL,
    `report_date`   datetime     DEFAULT NULL COMMENT '报告日期',
    `report_name`   varchar(255) DEFAULT NULL COMMENT '报告名称',
    `report_type`   varchar(255) DEFAULT NULL COMMENT '报告类型',
    `with_contacts` tinyint(4) NOT NULL DEFAULT '0' COMMENT '观点报告是否存在管理人联系信息（包括联系电话、地址、姓名等敏感信息）',
    `isvalid`       int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`     int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`     int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`    datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`    datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='报告基础信息表';

CREATE TABLE `daq_report_fund_info`
(
    `id`                        int(11) NOT NULL AUTO_INCREMENT COMMENT '主键，自动递增',
    `file_id`                   int(11) NOT NULL,
    `fund_name`                 varchar(255)   DEFAULT NULL COMMENT '基金的名称',
    `fund_code`                 varchar(50)    DEFAULT NULL COMMENT '基金的唯一识别代码',
    `company_name`              varchar(255)   DEFAULT NULL COMMENT '基金管理人的名称',
    `currency`                  varchar(20)    DEFAULT NULL COMMENT '基金交易使用的货币种类',
    `custodian_name`            varchar(255)   DEFAULT NULL COMMENT '基金托管人',
    `advisor_name`              varchar(255)   DEFAULT NULL COMMENT '投资顾问',
    `operation_type`            varchar(20)    DEFAULT NULL COMMENT '基金运作方式',
    `inception_date`            date           DEFAULT NULL COMMENT '基金成立日期',
    `investment_objective`      text COMMENT '投资目标',
    `fund_strategy_description` text COMMENT '投资策略',
    `secondary_benchmark`       varchar(255)   DEFAULT NULL COMMENT '业绩比较基准',
    `risk_return_desc`          text COMMENT '风险收益特征',
    `due_date`                  date           DEFAULT NULL COMMENT '基金到期日期',
    `reviewed`                  int(11) DEFAULT NULL COMMENT '信息披露报告是否经托管机构复核',
    `leverage`                  decimal(22, 6) DEFAULT NULL COMMENT '杠杆比例',
    `leverage_note`             text COMMENT '杠杆比例描述',
    `industry_trend`            text COMMENT '行业趋势',
    `fund_manager`              text COMMENT '基金经理描述',
    `isvalid`                   tinyint(4) NOT NULL DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效',
    `creatorid`                 int(11) NOT NULL COMMENT '创建者Id',
    `updaterid`                 int(11) NOT NULL COMMENT '修改者Id',
    `createtime`                datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updatetime`                datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='报告解析结果之基金信息表';

CREATE TABLE `daq_report_fund_transaction`
(
    `id`                        int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `file_id`                   int(11) NOT NULL,
    `fund_account`              varchar(100)   DEFAULT NULL COMMENT '基金账户编号',
    `fund_name`                 varchar(100)   DEFAULT NULL COMMENT '基金名称',
    `distributor`               varchar(100)   DEFAULT NULL COMMENT '销售此基金产品的经销商或银行',
    `transaction_type`          varchar(50)    DEFAULT NULL COMMENT '业务类型（例如：申购、赎回）',
    `business_reason`           varchar(100)   DEFAULT NULL COMMENT '业务操作的原因或类型说明',
    `status`                    varchar(50)    DEFAULT NULL COMMENT '交易确认的状态（例如：已确认、待处理等）',
    `holding_date`              date           DEFAULT NULL COMMENT '交易确认的日期',
    `apply_date`                date           DEFAULT NULL COMMENT '申请的日期',
    `apply_amount`              decimal(22, 6) DEFAULT NULL COMMENT '申请的金额',
    `apply_share`               decimal(22, 6) DEFAULT NULL COMMENT '申请的基金份额数量',
    `amount`                    decimal(22, 6) DEFAULT NULL COMMENT '确认的金额',
    `share`                     decimal(22, 6) DEFAULT NULL COMMENT '确认的基金份额数量',
    `net_amount`                decimal(22, 6) DEFAULT NULL COMMENT '净认购/申购的金额，确认净额',
    `nav`                       decimal(22, 6) DEFAULT NULL COMMENT '单位净值',
    `confirmation_ratio`        decimal(22, 6) DEFAULT NULL COMMENT '确认比例',
    `ta_confirmation_number`    varchar(100)   DEFAULT NULL COMMENT '交易授权确认编号',
    `ta_number`                 varchar(100)   DEFAULT NULL COMMENT 'TA代码',
    `apply_no`                  varchar(100)   DEFAULT NULL COMMENT '申请单号',
    `share_balance`             decimal(22, 6) DEFAULT NULL COMMENT '份额余额',
    `share_category`            varchar(50)    DEFAULT NULL COMMENT '份额类别',
    `large_redemption_type`     varchar(50)    DEFAULT NULL COMMENT '巨额赎回方式',
    `reward_mark`               varchar(50)    DEFAULT NULL COMMENT '提成或保底标志',
    `holding_days`              int(11) DEFAULT NULL COMMENT '持有天数',
    `share_registry_date`       date           DEFAULT NULL COMMENT '份额明细注册日期',
    `fee`                       decimal(22, 6) DEFAULT NULL COMMENT '总费用',
    `interest`                  decimal(22, 6) DEFAULT NULL COMMENT '利息',
    `interest_to_fund_assets`   decimal(22, 6) DEFAULT NULL COMMENT '利息转份额/利息归基金资产',
    `trade_fee`                 decimal(22, 6) DEFAULT NULL COMMENT '交易费',
    `default_fee`               decimal(22, 6) DEFAULT NULL COMMENT '违约金',
    `performance_fee`           decimal(22, 6) DEFAULT NULL COMMENT '业绩报酬',
    `fee_discounts`             decimal(22, 6) DEFAULT NULL COMMENT '费用折扣',
    `performance_fee_discounts` decimal(22, 6) DEFAULT NULL COMMENT '业绩报酬折扣',
    `dividend_type`             varchar(50)    DEFAULT NULL COMMENT '分红方式',
    `dividend_registry_date`    date           DEFAULT NULL COMMENT '分红登记日',
    `dividend_payment_date`     date           DEFAULT NULL COMMENT '红利发放日',
    `base_share_dividend`       decimal(22, 6) DEFAULT NULL COMMENT '分红基数份额',
    `dividend_mode`             varchar(50)    DEFAULT NULL COMMENT '分红模式',
    `unit_dividend`             decimal(22, 6) DEFAULT NULL COMMENT '单位分红',
    `dividend_per_unit`         decimal(22, 6) DEFAULT NULL COMMENT '每单位分红',
    `total_dividend_amount`     decimal(22, 6) DEFAULT NULL COMMENT '红利总额',
    `actual_cash_dividend`      decimal(22, 6) DEFAULT NULL COMMENT '实发现金红利',
    `frozen_shares`             decimal(22, 6) DEFAULT NULL COMMENT '冻结份额',
    `frozen_amount`             decimal(22, 6) DEFAULT NULL COMMENT '冻结金额',
    `actual_performance_amount` decimal(22, 6) DEFAULT NULL COMMENT '实际业绩提成金额',
    `actual_performance_share`  decimal(22, 6) DEFAULT NULL COMMENT '实际提成份额',
    `isvalid`                   int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`                 int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`                 int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`                datetime       DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`                datetime       DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    `is_sync`                   tinyint(3) NOT NULL DEFAULT '0' COMMENT '是否同步(0-否；1-是)',
    PRIMARY KEY (`id`),
    KEY                         `file_id` (`file_id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='交易流水表';

CREATE TABLE `daq_report_investor_info`
(
    `id`                 int(11) NOT NULL AUTO_INCREMENT COMMENT '主键，自动递增',
    `file_id`            int(11) NOT NULL,
    `investor_name`      varchar(255) DEFAULT NULL COMMENT '投资人的姓名',
    `investor_type`      varchar(50)  DEFAULT NULL COMMENT '投资人的类别（例如：个人、机构）',
    `certificate_type`   varchar(50)  DEFAULT NULL COMMENT '证件类型（例如：身份证、护照）',
    `certificate_number` varchar(50)  DEFAULT NULL COMMENT '投资人证件号码',
    `fund_account`       varchar(50)  DEFAULT NULL COMMENT '基金账户编号',
    `trading_account`    varchar(50)  DEFAULT NULL COMMENT '投资者交易账号',
    `isvalid`            tinyint(4) NOT NULL DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效',
    `creatorid`          int(11) NOT NULL COMMENT '创建者Id',
    `updaterid`          int(11) NOT NULL COMMENT '修改者Id',
    `createtime`         datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updatetime`         datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`),
    KEY                  `file_id` (`file_id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='报告解析结果之投资者信息表';

CREATE TABLE `daq_mailbox_info`
(
    `id`          int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `type`        int(11) DEFAULT NULL COMMENT '邮箱类型:1-QQ邮箱,2-腾讯企业邮箱,3-网易邮箱,4-新浪邮箱,99-其他',
    `email`       varchar(255) DEFAULT NULL COMMENT '邮箱账号',
    `password`    varchar(255) DEFAULT NULL COMMENT '邮箱密码',
    `protocol`    varchar(255) DEFAULT NULL COMMENT '协议',
    `server`      varchar(255) DEFAULT NULL COMMENT '收件服务器',
    `port`        varchar(255) DEFAULT NULL COMMENT '端口',
    `cron`        varchar(255) DEFAULT NULL COMMENT 'cron表达式',
    `open_status` int(11) DEFAULT '0' COMMENT '是否开启，0-不开启，1-开启',
    `description` text COMMENT '备注信息',
    `isvalid`     int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`   int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`   int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`  datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`  datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='邮箱信息表';

CREATE TABLE `daq_email_file_info`
(
    `id`         int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `email_id`   int(11) NOT NULL COMMENT '邮件id',
    `fund_id`    int(11) DEFAULT NULL COMMENT '基金id',
    `file_name`  varchar(255)  NOT NULL COMMENT '附件名称',
    `file_path`  varchar(1024) NOT NULL COMMENT '附件路径',
    `ai_parse`   tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否利用ai工具来解析的',
    `ai_file_id` varchar(64) DEFAULT NULL COMMENT 'ai解析时上传的文件id（方便重新解析）',
    `isvalid`    tinyint(4) NOT NULL DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效',
    `creatorid`  int(11) NOT NULL COMMENT '创建者Id',
    `updaterid`  int(11) NOT NULL COMMENT '修改者Id',
    `createtime` datetime    DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updatetime` datetime    DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='邮件附件信息表';

CREATE TABLE `daq_email_parse_info`
(
    `id`           int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `sender_email` varchar(255) DEFAULT NULL COMMENT '邮件发送方',
    `email`        varchar(255) DEFAULT NULL COMMENT '邮箱地址',
    `email_key`    varchar(64)  DEFAULT NULL,
    `email_date`   datetime     DEFAULT NULL COMMENT '邮箱日期',
    `parse_date`   datetime     DEFAULT NULL COMMENT '解析日期',
    `email_title`  varchar(255) DEFAULT NULL COMMENT '邮件主题',
    `email_type`   int(11) DEFAULT NULL,
    `parse_status` int(11) DEFAULT NULL COMMENT '解析状态',
    `fail_reason`  text COMMENT '失败原因',
    `attr_size`    int(11) DEFAULT NULL COMMENT '附件文件大小，byte',
    `isvalid`      int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`    int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`    int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime`   datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime`   datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='邮件解析信息表';

CREATE TABLE `daq_email_field_mapping`
(
    `id`         int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `code`       varchar(255) DEFAULT NULL COMMENT '字段编码',
    `name`       text COMMENT '字段(多个以英文逗号隔开)',
    `type`       int(11) DEFAULT NULL COMMENT '3-定期报告，4-交易流水确认函，0-共用的',
    `isvalid`    int(11) DEFAULT '1' COMMENT '记录的有效性；1-有效；0-无效；',
    `creatorid`  int(11) DEFAULT NULL COMMENT '创建者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `updaterid`  int(11) DEFAULT NULL COMMENT '修改者Id;第一次创建时与Creator值相同，修改时与修改人值相同',
    `createtime` datetime     DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime` datetime     DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='邮件字段映射表';

CREATE TABLE `daq_task_record`
(
    `id`         int(11) NOT NULL AUTO_INCREMENT COMMENT '主键Id',
    `task_key`   varchar(50) NOT NULL COMMENT '任务的标识',
    `start_time` datetime DEFAULT NULL COMMENT '任务开始执行的时间',
    `end_time`   datetime DEFAULT NULL COMMENT '任务执行结束时的时间',
    `status`     int(4) DEFAULT '0' COMMENT '任务执行状态，0-执行中，1-执行完成，2-执行失败',
    `err_msg`    text COMMENT '任务执行失败时的信息',
    `createtime` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间,默认第一次创建的getdate()时间',
    `updatetime` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间;第一次创建时与CreatTime值相同，修改时与修改时间相同',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='任务执行记录表（轮询任务的执行记录表，前面的任务未执行完成时不允许重复执行）';



INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundName', '基金名称,产品名称,产品全称,基金产品,名称,资产名称,账户名称,账套名称,子产品名称,项目名称,产品名称全称', 0, 1, null, null, '2025-02-20 15:54:06', '2025-05-07 14:24:43');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundCode', '备案编码,协会备案编号,协会备案编码,协会备案代码,基金协会代码,产品编码,产品代码,产品备案号,产品备案编码,基金代码,基金编码,资产代码,代码,子产品代码,协会代码,基金编号', 0, 1, null, null, null, '2025-05-12 11:56:07');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('companyName', '管理人,基金管理人', 0, 1, null, null, '2025-02-20 15:54:06', '2025-02-20 15:54:06');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('currency', '币种,货币种类', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('investorName', '投资人,客户名称,投资者名称,投资者姓名,投资者,投资人名称,委托人名称,委托人姓名', 4, 1, null, null, '2025-02-20 16:05:35', '2025-03-18 16:07:36');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('investorType', '投资人类别,投资者类型,投资人类型', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-22 09:18:54');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('certificateType', '证件类型,投资者证件类型', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('certificateNumber', '证件号码,投资者证件号码', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fundAccount', '基金账号,投资者基金账号', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('tradingAccount', '交易账号,投资者交易账号', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('distributor', '销售商,销售机构,网点', 4, 1, null, null, '2025-02-20 16:05:35', '2025-02-20 16:05:35');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('nav', '单位净值,单位净值元,当日单位净值,今日单位净值,计提前单位净值,实际净值,基金净值,资产份额净值,资产份额净值元,份额净值,基金份额净值,基金份额净值元,基金单位净值,虚拟净值提取前单位净值,报告期期末单位净值,虚拟计提前单位净值,试算前单位净值,期末单位净值,子产品单位净值,产品单位净值,本级别单位净值,委托资产份额净值元,期末基金份额净值', 0, 1, null, null, '2025-02-20 17:17:20', '2025-05-09 16:03:05');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('transactionType', '业务类型,业务代码,业务类别', 4, 1, null, null, '2025-02-20 18:07:51', '2025-03-11 18:32:56');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('businessReason', '业务类型原因,失败原因,原因', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('status', '确认状态', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('holdingDate', '确认日期,交易确认日期', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyDate', '申请日期', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyAmount', '申请的金额,申请金额,申请金额(元)', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:39');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyShare', '申请的份额,申请份额,申请的基金份额数量', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('amount', '确认的金额,确认金额,确认金额(元),业绩报酬计提金额,再投资金额,再投资红利金额,原确认金额', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:39');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('share', '确认的份额,确认份额,扣减份额,再投资份额,持有份额', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-28 17:28:30');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('netAmount', '净认购/申购的金额,确认净额', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('fee', '交易费,手续费用,交易费(元),手续费用(元),总费用,总费用(元),再投资费用', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:38');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('confirmationRatio', '确认比例', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('taConfirmationNumber', 'TA确认号,TA确认编号,确认单号,TA确认单号', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:38');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('interest', '利息,利息(元)', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-22 11:04:38');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('interestToFundAssets', '利息转份额,利息归基金资产', 4, 1, null, null, '2025-02-20 18:07:51', '2025-02-20 18:08:10');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('applyNo', '申请单号', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('shareBalance', '份额余额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('shareCategory', '份额类别', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('largeRedemptionType', '巨额赎回方式', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('tradeFee', '交易费,交易费(元)', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('defaultFee', '违约金,违约金(元)', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('performanceFee', '业绩报酬,业绩报酬(元)', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('feeDiscounts', '费用折扣', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('performanceFeeDiscounts', '业绩报酬折扣', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendRegistryDate', '分红登记日', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendPaymentDate', '红利发放日,红利下发日', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('baseShareDividend', '分红基数份额,分红总份额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendMode', '分红模式', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('unitDividend', '单位分红', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendPerUnit', '每单位分红', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('totalDividendAmount', '红利总额,分红总金额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('actualCashDividend', '实发现金红利,实际所得现金红利', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('frozenShares', '冻结份额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('frozenAmount', '冻结金额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('actualPerformanceAmount', '实际业绩提成金额,实际提成金额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('actualPerformanceShare', '实际提成份额,实际业绩提成份额', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('rewardMark', '提成或保底标志', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('holdingDays', '持有天数', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('shareRegistryDate', '份额明细注册日期', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('taNumber', 'TA代码', 4, 1, null, null, '2025-02-22 11:04:39', '2025-02-22 11:05:32');
INSERT INTO daq_email_field_mapping (code, name, type, isvalid, creatorid, updaterid, createtime, updatetime) VALUES ('dividendType', '分红方式', 4, 1, null, null, '2025-02-22 13:41:57', '2025-02-28 17:30:31');

